@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: hjsmin
 version: 0.2.0.1
-id: hjsmin-0.2.0.1-46670f54640c2d75932d2d7d196eac09
-key: hjsmi_2DQCkN6Ap7iCiYZ3pBgxpD
+id: hjsmin-0.2.0.1-9b584074a533f56bfeee2bd0e05cbecb
+key: hjsmi_4UWKiOQjjeZ20FGf3kDJhu
 license: BSD3
 maintainer: Erik de Castro Lopo <erikd@mega-nerd.com>
 stability: unstable
@@ -22,13 +22,13 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/hjsmin-0.2.0.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/hjsmin-0.2.0.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/hjsmin-0.2.0.1
-hs-libraries: HShjsmin-0.2.0.1-2DQCkN6Ap7iCiYZ3pBgxpD
+hs-libraries: HShjsmin-0.2.0.1-4UWKiOQjjeZ20FGf3kDJhu
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    language-javascript-0.6.0.2-b872ffab7eb92e354d2028cc73df3cc6
+    language-javascript-0.6.0.4-c43c009634450c277e20aa280373fe2a
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
 haddock-interfaces: /usr/share/doc/haskell-hjsmin/html/hjsmin.haddock
 haddock-html: /usr/share/doc/haskell-hjsmin/html
